Enum valkyrie_ast::NamespaceKind
source · pub enum NamespaceKind {
Main,
Standalone,
Test,
Hide,
}Expand description
The kind of namespace
Variants
Main
Main namespace where definitions and imports can be shared
Standalone
Independent namespace, isolated definitions, except public and main definitions
Test
This is a test file, only available in the test environment
Hide
Temporarily remove a file
Implementations