pub enum ParameterTerm {
    LMark,
    RMark,
    Single {
        annotations: AnnotationNode,
        key: IdentifierNode,
        bound: Option<ExpressionKind>,
        default: Option<ExpressionKind>,
    },
    UnpackList {
        modifiers: ModifierList,
        key: IdentifierNode,
        bound: Option<ExpressionKind>,
    },
    UnpackDict {
        modifiers: ModifierList,
        key: IdentifierNode,
        bound: Option<ExpressionKind>,
    },
}
T: Type = type_expression

Variants



LMark

<

The type on the left cannot be called by name, but the type on the right can be called by name.



RMark

>

The type on the left can be called by name, and the type on the right must be called by name.



Single

Fields

annotations: AnnotationNode

The modifiers apply on the parameter

key: IdentifierNode

The name

bound: Option<ExpressionKind>

The type boundary of the parameter

default: Option<ExpressionKind>

The default value of the parameter

#annotation modifier a: Type = default



UnpackList

Fields

modifiers: ModifierList

The modifiers apply on the parameter

key: IdentifierNode

The list receiver name

bound: Option<ExpressionKind>

The type boundary of the parameter

#annotation modifier ..list: Type



UnpackDict

Fields

modifiers: ModifierList

The modifiers apply on the parameter

key: IdentifierNode

The dict receiver name

bound: Option<ExpressionKind>

The type boundary of the parameter

#annotation modifier ...dict: Type