pub enum NamespaceKind {
    Main,
    Standalone,
    Test,
    Hide,
}
The kind of namespace

Variants



Main

Main namespace where definitions and imports can be shared



Standalone

Independent namespace, isolated definitions, except public and main definitions



Test

This is a test file, only available in the test environment



Hide

Temporarily remove a file

Implementations

source

impl NamespaceKind

source

pub fn as_str(&self) -> &'static str

Get the string representation of the namespace kind