Enum valkyrie_ast::ParameterTerm
source · pub enum ParameterTerm {
LMark,
RMark,
Single {
annotations: AnnotationNode,
key: IdentifierNode,
bound: Option<ExpressionKind>,
default: Option<ExpressionKind>,
},
UnpackList {
modifiers: ModifierList,
key: IdentifierNode,
bound: Option<ExpressionKind>,
},
UnpackDict {
modifiers: ModifierList,
key: IdentifierNode,
bound: Option<ExpressionKind>,
},
}Expand description
T: Type = type_expression
Variants
LMark
<
The type on the left cannot be called by name, but the type on the right can be called by name.
RMark
>
The type on the left can be called by name, and the type on the right must be called by name.
Single
Fields

annotations: AnnotationNodeThe modifiers apply on the parameter

key: IdentifierNodeThe name

bound: Option<ExpressionKind>The type boundary of the parameter

default: Option<ExpressionKind>The default value of the parameter
#annotation modifier a: Type = default
UnpackList
Fields

modifiers: ModifierListThe modifiers apply on the parameter

key: IdentifierNodeThe list receiver name

bound: Option<ExpressionKind>The type boundary of the parameter
#annotation modifier ..list: Type
UnpackDict
Fields

modifiers: ModifierListThe modifiers apply on the parameter

key: IdentifierNodeThe dict receiver name

bound: Option<ExpressionKind>The type boundary of the parameter
#annotation modifier ...dict: Type